@@ -154,8 +154,16 @@ def __run_compare(source_file_path, target_path, export_text, output_type, csv_s
 
         __process_file(source_file_content, target_file_content, export_text, output_type, csv_sep, min_match_length,
                        look_ahead_limit, look_back_limit, max_merge_distance, max_merge_ellipsis_distance,
-                       output_folder_path, filename, keep_ambiguous_matches)
+                       output_folder_path, filename, keep_ambiguous_matches, None, None)
     else:
+        start_time = time.perf_counter()
+        quid = Quid(min_match_length, look_back_limit, look_ahead_limit, max_merge_distance,
+                    max_merge_ellipsis_distance, export_text, keep_ambiguous_matches)
+        min_length_match_positions, hashes = quid.prepare_source_data(source_file_content)
+
+        end_time = time.perf_counter()
+        logging.info(f'\n--- Runtime prepare source: {end_time - start_time: .2f} seconds ---')
+
         pool = multiprocessing.Pool(num_of_processes)
 
         for file_or_folder in listdir(target_path):
@@ -170,7 +178,8 @@ def __run_compare(source_file_path, target_path, export_text, output_type, csv_s
                                                        output_type, csv_sep, min_match_length, look_ahead_limit,
                                                        look_back_limit, max_merge_distance,
                                                        max_merge_ellipsis_distance, output_folder_path,
-                                                       filename, keep_ambiguous_matches))
+                                                       filename, keep_ambiguous_matches, min_length_match_positions,
+                                                       hashes))
 
         pool.close()
         pool.join()
@@ -178,10 +187,11 @@ def __run_compare(source_file_path, target_path, export_text, output_type, csv_s
 
 def __process_file(source_file_content, target_file_content, export_text, output_type, csv_sep, min_match_length,
                    look_ahead_limit, look_back_limit, max_merge_distance, max_merge_ellipsis_distance,
-                   output_folder_path, filename, keep_ambiguous_matches):
+                   output_folder_path, filename, keep_ambiguous_matches, cached_min_length_match_positions,
+                   cached_hashes):
     quid = Quid(min_match_length, look_back_limit, look_ahead_limit, max_merge_distance, max_merge_ellipsis_distance,
                 export_text, keep_ambiguous_matches)
-    matches = quid.compare(source_file_content, target_file_content)
+    matches = quid.compare(source_file_content, target_file_content, cached_min_length_match_positions, cached_hashes)
 
     if not export_text:
         for match in matches:
@@ -283,11 +293,6 @@ def __run_passager(source_file_path, target_folder_path, matches_folder_path, ou
         content = json.dumps(analyzed_work.citation_source_links, default=__json_encoder_passager)
         citation_source_links_output_file.write(content)
 
-    # with open(join(output_folder_path, 'important_segment_links.json'), 'w', encoding='utf-8') as \
-    #         important_segment_links_output_file:
-    #     content = json.dumps(analyzed_work.important_segment_links, default=__json_encoder_passager)
-    #     important_segment_links_output_file.write(content)
-
 
 def __run_visualize(source_file_path, target_folder_path, passages_folder_path, output_folder_path, title, author,
                     year, censor):
@@ -329,8 +334,6 @@ def __run_visualize(source_file_path, target_folder_path, passages_folder_path,
 
     copyfile(join(passages_folder_path, 'citation_source_links.json'), join(output_folder_path,
                                                                             'citation_source_links.json'))
-    # copyfile(join(passages_folder_path, 'important_segment_links.json'), join(output_folder_path,
-    #                                                                           'important_segment_links.json'))
     copyfile(join(passages_folder_path, 'target_text_location_links.json'), join(output_folder_path,
                                                                                  'target_text_location_links.json'))
 
