@@ -77,11 +77,33 @@ class Quid:
         self.include_text_in_result = include_text_in_result
         self.keep_ambiguous_matches = keep_ambiguous_matches
 
-    def compare(self, source_text: str, target_text: str) -> List[Match]:
+    def prepare_source_data(self, source_text: str):
+        """
+        Takes a source text and returns a tuple consisting of a map and a list of hashes. The map maps strings to their
+        starting positions in the text.
+        :param source_text: The source text
+        :return: A tuple consisting of a map of strings and their starting positions and a list of hashes of the strings
+        in the map.
+        """
+        input_texts: List[str] = [source_text]
+        self.texts, self.tokens = self.__read_input(input_texts)
+        return self.__prepare_source_data(self.texts[0])
+
+    def __prepare_source_data(self, text: Text):
+        min_length_match_positions: Dict[str, List[int]]
+        hashes: MinHashLSH
+        min_length_match_positions, hashes = self.__make_min_length_match_starting_positions(text)
+        return min_length_match_positions, hashes
+
+    def compare(self, source_text: str, target_text: str,
+                cached_min_length_match_positions: Dict[str, List[int]] = None,
+                cached_hashes: MinHashLSH = None) -> List[Match]:
         """
         Compare the two input texts and return a list of matching sequences.
         :param source_text: A source text
         :param target_text: A target text
+        :param cached_min_length_match_positions: A map of strings to their starting positions in the source text
+        :param cached_hashes: A MinHashLSH object
         :return: A list of found matches
         """
 
@@ -92,9 +114,12 @@ class Quid:
         self.texts, self.tokens = self.__read_input(input_texts)
         self.forward_references = {}
 
-        min_length_match_positions: Dict[str, List[int]]
-        hashes: MinHashLSH
-        min_length_match_positions, hashes = self.__make_min_length_match_starting_positions(self.texts[0])
+        if not cached_min_length_match_positions or not cached_hashes:
+            min_length_match_positions, hashes = self.__prepare_source_data(self.texts[0])
+        else:
+            min_length_match_positions = cached_min_length_match_positions
+            hashes = cached_hashes
+
         self.__make_forward_references(self.texts[1], min_length_match_positions, hashes)
         matches: List[InternalMatch] = self.__get_similarities(self.texts[0], self.texts[1])
         matches.sort(key=lambda x: x.target_match_span.character_start, reverse=False)
@@ -165,13 +190,11 @@ class Quid:
         input_text = re.sub('[.;!?]', self.SENTENCE_DELIMITER, input_text)
 
         # preserve [s], [n] [er ]etc.
-        # input_text = re.sub(r'(\w)\[([a-zA-Z])]', '\\g<1>\u2191\\g<2>\u2191', input_text)
         input_text = re.sub(r'\[([a-zA-Z]{1,3})]', '\u2191\\g<1>\u2191', input_text)
 
         input_text = re.sub(rf'[^\w_@{self.SENTENCE_DELIMITER}\u2191 ]', ' ', input_text)
         input_text = re.sub(r'\d', ' ', input_text)
 
-        # input_text = re.sub(r'(\w)\u2191([a-zA-Z])\u2191', '\\g<1>[\\g<2>]', input_text)
         input_text = re.sub(r'\u2191([a-zA-Z]{1,3})\u2191', '[\\g<1>]', input_text)
 
         return input_text.lower()
@@ -488,7 +511,6 @@ class Quid:
         if min(input1_length, input2_length) < 2:
             return input1 == input2
 
-        # ratio = fuzz.ratio(input1, input2)
         ratio = Levenshtein.normalized_similarity(input1, input2)
 
         if max(input1_length, input2_length) < 10:
@@ -658,16 +680,17 @@ class Quid:
     def __remove_too_short_matches(self, matches: List[InternalMatch]):
         """
         Removes matches which are shorter than a threshold.
-        @param matches: The list of matches to check.
-        @return: The remaining matches.
+        :param matches: The list of matches to check.
+        :return: The remaining matches.
         """
         result: List[InternalMatch] = []
 
         for match in matches:
-            if match.target_match_span.token_length >= self.min_match_length:
+            if (match.target_match_span.token_length >= self.min_match_length and
+                    match.source_match_span.token_length >= self.min_match_length):
                 result.append(match)
             elif (match.target_match_span.token_length >= self.min_match_length - 1 and
-                  self.tokens[match.target_match_span.token_start_pos].text.startswith('@')):
+                    self.tokens[match.target_match_span.token_start_pos].text.startswith('@')):
                 result.append(match)
             elif (match.target_match_span.token_length >= self.min_match_length - 1 and
                   match.target_match_span.token_start_pos - 1 >= self.texts[0].tk_end_pos and
@@ -680,8 +703,8 @@ class Quid:
     def __remove_boundary_overshoot(self, matches: List[InternalMatch]):
         """
         Remove tokens after sentence delimiters if they're likely to have matched by accident.
-        @param matches: The list of matches to check.
-        @return: The cleaned matches.
+        :param matches: The list of matches to check.
+        :return: The cleaned matches.
         """
         for match in matches:
             current_source_match_span = match.source_match_span
