@@ -1,9 +1,6 @@
 import copy
-import re
 from typing import List, Dict
 
-from quid.passager.ImportantSegment import ImportantSegment
-from quid.passager.ImportantSegmentLink import ImportantSegmentLink
 from quid.passager.AnalyzedWork import AnalyzedWork
 from quid.passager.Location import Location
 from quid.passager.TargetMatch import TargetMatch
