@@ -1,9 +1,12 @@
+from dataclasses import dataclass
+
+
+@dataclass
 class TargetLocation:
-    def __init__(self, my_id, start, end, text):
-        self.my_id = my_id
-        self.start = start
-        self.end = end
-        self.text = text
+    my_id: int
+    start: int
+    end: int
+    text: str
 
     def __hash__(self) -> int:  # pragma: no cover
         return hash((self.my_id, self.start, self.end))
